@@ -248,12 +248,6 @@ int add_job_to_queue(gearman_client_st **client, gm_server_t * server_list[GM_LI
     return GM_OK;
 }
 
-
-void *dummy(__attribute__((unused)) gearman_job_st *job, __attribute__((unused)) void *context, size_t *result_size, __attribute__((unused)) gearman_return_t *ret_ptr ) {
-    *result_size = 0;
-    return NULL;
-}
-
 /* free client structure */
 void gm_free_client(gearman_client_st **client) {
     if(client == NULL)
@@ -267,14 +261,17 @@ void gm_free_client(gearman_client_st **client) {
 
 /* free worker structure */
 void gm_free_worker(gearman_worker_st **worker) {
-    if(worker == NULL)
+    gearman_worker_st *temp_worker = NULL;
+
+    if(worker == NULL) {
         return;
-    if(*worker == NULL)
+    }
+    if(*worker == NULL) {
         return;
-    gearman_worker_unregister_all(*worker);
-    gearman_worker_remove_servers(*worker);
-    gearman_worker_free(*worker);
+    }
+    temp_worker = *worker;
     *worker = NULL;
+    gearman_worker_free(temp_worker);
 }
 
 /* get worker/jobs data from gearman server */
@@ -331,12 +328,6 @@ int get_gearman_server_data(mod_gm_server_status_t *stats, char ** message, char
         func.worker  = atoi(worker);
         func.waiting = func.total - func.running;
 
-        /* skip the dummy queue if its empty */
-        if(!strcmp(name, "dummy") && func.total == 0) {
-            free(func.queue);
-            continue;
-        }
-
         stats->function[stats->function_num++] = func;
         gm_log( GM_LOG_DEBUG, "%i: name:%-20s worker:%-5i waiting:%-5i running:%-5i\n", stats->function_num, func.queue, func.worker, func.waiting, func.running );
     }
